searchData={"items":[{"type":"module","title":"Torus","doc":"Torus is a plug-and-play library that seamlessly integrates PostgreSQL's search into Ecto, streamlining the construction of advanced search queries.","ref":"Torus.html"},{"type":"module","title":"Usage - Torus","doc":"The package can be installed by adding `torus` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:torus, \"~> 0.2.0\"}\n  ]\nend\n```\n\nThen, in any query, you can (for example) add a full-text search:\n\n```elixir\nPost\n|> Torus.full_text_dynamic([p], [p.title, p.body], \"uncovered hogwarts\")\n|> Repo.all()\n```\n\nSee `full_text_dynamic/5` for more details.","ref":"Torus.html#module-usage"},{"type":"module","title":"5 types of searches: - Torus","doc":"1.  **Similarity**: Searches for items that are closely alike based on attributes, often using measures like cosine similarity or Euclidean distance.\n\n    See `similarity/5` for more details.\n\n2.  **Text Search Vectors**: Uses term-document matrix vectors for **full-text search**, enabling\n    efficient querying and ranking based on term frequency. - [PostgreSQL: Documentation: 17: Chapter 12. Full Text Search](https://www.postgresql.org/docs/current/textsearch.html)\n\n    ```sql\n    SELECT to_tsvector('english', 'The quick brown fox jumps over the lazy dog') @@ to_tsquery('fox & dog');\n    ```\n\n    See `full_text_dynamic/5` for more details.\n\n3.  **Semantic Search**: Understands the contextual meaning of queries to match and retrieve related content, often utilizing natural language processing.\n    [Semantic Search with PostgreSQL and OpenAI Embeddings | by Dima Timofeev | Towards Data Science](https://towardsdatascience.com/semantic-search-with-postgresql-and-openai-embeddings-4d327236f41f)\n4.  **Hybrid Search**: Combines multiple search techniques (e.g., keyword and semantic) to leverage their strengths for more accurate results.\n5.  **3rd Party Engines/Providers**: Utilizes external services or software specifically designed for optimized and scalable search capabilities, such as Elasticsearch or Algolia.","ref":"Torus.html#module-5-types-of-searches"},{"type":"module","title":"Torus support - Torus","doc":"For now, Torus supports similarity and full-text search, with plans to expand support further. These docs will be updated with more examples on which search type to choose and how to make them more performant (by adding indexes or using specific functions).","ref":"Torus.html#module-torus-support"},{"type":"macro","title":"Torus.full_text_dynamic/5","doc":"Full text search with rank ordering. Accepts a list of columns to search in.\nCleans the term, so it can be input directly by the user.","ref":"Torus.html#full_text_dynamic/5"},{"type":"macro","title":"Example usage - Torus.full_text_dynamic/5","doc":"```elixir\niex> insert_post!(title: \"Hogwarts Shocker\", body: \"A spell disrupts the Quidditch Cup.\")\n...> insert_post!(title: \"Diagon Bombshell\", body: \"Secrets uncovered in the heart of Hogwarts.\")\n...> insert_post!(title: \"Completely unrelated\", body: \"No magic here!\")\n...>  Post\n...> |> Torus.full_text_dynamic([p], [p.title, p.body], \"uncovered hogwarts\")\n...> |> select([p], p.title)\n...> |> Repo.all()\n[\"Diagon Bombshell\"]\n```\n\nTODO: Add section on optimization, tradeoffs, etc.","ref":"Torus.html#full_text_dynamic/5-example-usage"},{"type":"macro","title":"Torus.ilike/5","doc":"Wrapper around postgres `ilike` function. Accepts a list of columns to search in.\n\n**Doesn't clean the term, so it needs to be sanitized before being passed in.**","ref":"Torus.html#ilike/5"},{"type":"macro","title":"Examples - Torus.ilike/5","doc":"```elixir\niex> insert_post!(title: \"Hogwarts Shocker\", body: \"A spell disrupts the Quidditch Cup.\")\n...> insert_post!(title: \"Diagon Bombshell\", body: \"Secrets uncovered in the heart of Hogwarts.\")\n...> insert_post!(title: \"Completely unrelated\", body: \"No magic here!\")\n...> Post\n...> |> Torus.ilike([p], [p.title, p.body], \"%ogw%\")\n...> |> select([p], p.title)\n...> |> order_by(:id)\n...> |> Repo.all()\n[\"Hogwarts Shocker\", \"Diagon Bombshell\"]\n```\n\nTODO: Add section on optimization, tradeoffs, etc.","ref":"Torus.html#ilike/5-examples"},{"type":"macro","title":"Torus.similarity/5","doc":"Wrapper around postgres `similarity` function. Accepts a list of columns to search in.\n\n**You need to have pg_trgm extension installed.**","ref":"Torus.html#similarity/5"},{"type":"macro","title":"Examples - Torus.similarity/5","doc":"```elixir\niex> insert_post!(title: \"Hogwarts Shocker\", body: \"A spell disrupts the Quidditch Cup.\")\n...> insert_post!(title: \"Diagon Bombshell\", body: \"Secrets uncovered in the heart of Hogwarts.\")\n...> insert_post!(title: \"Completely unrelated\", body: \"No magic here!\")\n...>  Post\n...> |> Torus.similarity([p], [p.title, p.body], \"boshel\", limit: 1)\n...> |> select([p], p.title)\n...> |> Repo.all()\n[\"Diagon Bombshell\"]\n```\n\n[Similarity search in postgres](https://postgresql.org/docs/17/interactive/pgtrgm.html#//apple_ref/cpp/Function/similarity).\n\nTODO: Add section on optimization, tradeoffs, etc.","ref":"Torus.html#similarity/5-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog for Torus v0.2.0\n\nTorus now supports full text search, ilike, and similarity search.","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}